@@ -1,29 +1,32 @@
-from operator import add
 from functools import reduce
+from operator import add
 
 import click
 
 from nbmanips import Notebook
-from nbmanips.cli import get_selector, export
+from nbmanips.cli import export, get_selector
 
 __all__ = [
     'cat',
 ]
 
 
-@click.command(help="Concatenate Jupyter FILE(s) to standard output")
+@click.command(help='Concatenate Jupyter FILE(s) to standard output')
 @click.argument('file', nargs=-1, required=True)
 @click.option('--output', '-o', default=None)
 @click.option(
-    '--force', '-f', is_flag=True, default=False,
-    help='Do not prompt for confirmation if file already exists'
+    '--force',
+    '-f',
+    is_flag=True,
+    default=False,
+    help='Do not prompt for confirmation if file already exists',
 )
 @click.option(
     '--select',
     '-s',
     type=int,
     default=None,
-    help="Notebook to apply selector on. if unused, selector will be applied to all notebooks",
+    help='Notebook to apply selector on. if unused, selector will be applied to all notebooks',
 )
 def cat(file, select, output, force):
     nbs = [Notebook.read(notebook_path) for notebook_path in file]
